<?php

namespace Drupal\simple_oauth_claims\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Claim form.
 *
 * @property \Drupal\simple_oauth_claims\ClaimInterface $entity
 */
class ClaimForm extends EntityForm {

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    $form['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#maxlength' => 255,
      '#default_value' => $this->entity->label(),
      '#description' => $this->t('Label for the claim.'),
      '#required' => TRUE,
    ];
    $form['id'] = [
      '#type' => 'machine_name',
      '#default_value' => $this->entity->id(),
      '#machine_name' => [
        'exists' => '\Drupal\simple_oauth_claims\Entity\Claim::load',
      ],
      '#disabled' => !$this->entity->isNew(),
    ];
    $form['type'] = [
      '#type' => 'select',
      '#title' => $this->t('Type'),
      '#default_value' => $this->entity->getType(),
      '#description' => $this->t('Description of the claim.'),
      '#options' => [
        'private' => $this->t('Private claim'),
        'oidc' => $this->t('OpenID Connect claim'),
      ],
    ];
    $form['name'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Name'),
      '#default_value' => $this->entity->getName(),
      '#description' => $this->t('Description of the claim.'),
    ];
    $form['field_name'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Field name'),
      '#default_value' => $this->entity->getFieldName(),
      '#description' => $this->t('Description of the claim.'),
    ];
    $form['status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enabled'),
      '#default_value' => $this->entity->status(),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $result = parent::save($form, $form_state);
    $message_args = ['%label' => $this->entity->label()];
    $message = $result == SAVED_NEW
      ? $this->t('Created new claim %label.', $message_args)
      : $this->t('Updated claim %label.', $message_args);
    $this->messenger()->addStatus($message);
    $form_state->setRedirectUrl($this->entity->toUrl('collection'));

    // Trigger compiler run to take changes into effect.
    require DRUPAL_ROOT . '/core/includes/utility.inc';
    $class_loader = require DRUPAL_ROOT . '/autoload.php';
    \drupal_rebuild($class_loader, \Drupal::requestStack()->getCurrentRequest());

    return $result;
  }

}
